@@ -2,6 +2,7 @@ from abc import ABCMeta, abstractmethod
 from pathlib import Path
 from subprocess import CompletedProcess, run
 from typing import Any, List, Optional, Type, Union
+from typing import BinaryIO
 
 from pydantic import FilePath, PositiveFloat
 from pydantic.types import confloat, conint
@@ -153,7 +154,7 @@ class DSheetPilingModel(BaseModel):
     def model_type(self) -> Union[str, ModelType]:
         return self.datastructure.input_data.model.model
 
-    def serialize(self, filename: FilePath):
+    def serialize(self, filename: Union[FilePath, BinaryIO]):
         ds = self.datastructure.input_data.dict()
         ds.update(
             {
@@ -163,7 +164,8 @@ class DSheetPilingModel(BaseModel):
         )
         serializer = DSheetPilingInputSerializer(ds=ds)
         serializer.write(filename)
-        self.filename = filename
+        if isinstance(filename, Path):
+            self.filename = filename
 
     def _is_calculation_per_stage_required(self) -> bool:
         """Function that checks if [CALCULATION PER STAGE] can be modified. This is true for a verify sheet-piling calculation and method B."""
@@ -236,7 +238,8 @@ class DSheetPilingModel(BaseModel):
         Calculation options per stage are set in [CALCULATION OPTIONS PER STAGE].
 
         Args:
-            stage_id: Curvesettings are set to this stage. This refers to the Pythonic input and has a starting point of 0.
+            calculation_options_per_stage: Calculation options for stage
+            stage_id: Settings are set to this stage. This refers to the Pythonic input and has a starting point of 0.
 
         Raises:
             ValueError: When non-existing stage_id is passed or when no
@@ -278,10 +281,10 @@ class DSheetPilingModel(BaseModel):
     def set_calculation_options(self, calculation_options: CalculationOptions) -> None:
         """Set calculation options.
 
-        Calculation options per stage are set in [CALCULATION OPTIONS].
+        Overall calculation options are set in [CALCULATION OPTIONS].
 
         Args:
-            stage_id: Curvesettings are set to this stage.
+            calculation_options: Calculation options
         """
         if not issubclass(type(calculation_options), CalculationOptions):
             raise ValueError(
@@ -385,8 +388,7 @@ class DSheetPilingModel(BaseModel):
 
         Args:
             top_level: Top level of the sheet piling.
-            elements: List of sheet piling elements, can be Sheet, DiaphragmWall, or Pile.
-            Elements are sorted on sheetpilingelementlevel.
+            elements: List of sheet piling elements (can be Sheet, DiaphragmWall, or Pile elements) which are sorted on sheetpilingelementlevel.
         """
         self.datastructure.input_data.set_construction(
             top_level=top_level, elements=[element.to_internal() for element in elements]
